==> igniteui-react-charts-18.7.0-beta.2.tgz: package/esm2015/lib/igr-spline-series-base.js <==
import { SplineType_$type } from "./SplineType";
import { IgrHorizontalAnchoredCategorySeries } from "./igr-horizontal-anchored-category-series";
import { ensureBool, ensureEnum } from "igniteui-react-core";
/**
 * Represents the base class for all IgxDataChartComponent spline series.
*/
export class IgrSplineSeriesBase extends IgrHorizontalAnchoredCategorySeries {
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets or sets whether to include the spline shape in the axis range requested of the axis.
    */
    get isSplineShapePartOfRange() {
        return this.i.ach;
    }
    set isSplineShapePartOfRange(v) {
        this.i.ach = ensureBool(v);
    }
    /**
     * Gets whether the current series shows an area or line shape.
    */
    get isAreaOrLine() {
        return this.i.et;
    }
    /**
     * Gets or sets the type of spline to be rendered.
    *
    * ```ts
    * this.series.splineType = SplineType.Clamped;
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource} >
    *
    *     <IgrCategoryXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrSplineAreaSeries
    *      name="series1"
    *      valueMemberPath="value"/>
    *  </IgrDataChart>
    * ```
    */
    get splineType() {
        return this.i.acg;
    }
    set splineType(v) {
        this.i.acg = ensureEnum(SplineType_$type, v);
    }
}

==> igniteui-react-charts-18.7.5-beta.2.tgz: package/esm2015/lib/igr-spline-series-base.js <==
import { SplineType_$type } from "./SplineType";
import { IgrHorizontalAnchoredCategorySeries } from "./igr-horizontal-anchored-category-series";
import { ensureBool, ensureEnum } from "igniteui-react-core";
/**
 * Represents the base class for all IgxDataChartComponent spline series.
*/
export class IgrSplineSeriesBase extends IgrHorizontalAnchoredCategorySeries {
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets or sets whether to include the spline shape in the axis range requested of the axis.
    */
    get isSplineShapePartOfRange() {
        return this.i.ac1;
    }
    set isSplineShapePartOfRange(v) {
        this.i.ac1 = ensureBool(v);
    }
    /**
     * Gets whether the current series shows an area or line shape.
    */
    get isAreaOrLine() {
        return this.i.ev;
    }
    /**
     * Gets or sets the type of spline to be rendered.
    *
    * ```ts
    * this.series.splineType = SplineType.Clamped;
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource} >
    *
    *     <IgrCategoryXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrSplineAreaSeries
    *      name="series1"
    *      valueMemberPath="value"/>
    *  </IgrDataChart>
    * ```
    */
    get splineType() {
        return this.i.ac0;
    }
    set splineType(v) {
        this.i.ac0 = ensureEnum(SplineType_$type, v);
    }
}
